package com.sw.patroleditor.controller;

import com.sw.patroleditor.common.ResultData;
import com.sw.patroleditor.domain.vo.AreaVO;
import com.sw.patroleditor.exception.ErrorCode;
import com.sw.patroleditor.service.AreaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * Created by shiwn on 2024/8/8 16:09
 */
@Api(tags = {"区域接口"})
@RestController
@RequestMapping("area")
public class AreaController {
    @Resource
    private AreaService areaService;

    @ApiOperation(value = "保存区域")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "vo", value = "数据", dataType = "AreaVO", required = true)
    })
    @PostMapping("/addArea")
    public ResultData addArea(@RequestBody AreaVO vo) {
        int flag = areaService.addArea(vo);
        if (flag > 0) {
            return ResultData.success();
        } else {
            return ResultData.fail(ErrorCode.FAIL);
        }
    }

    @ApiOperation(value = "删除区域")
    @PostMapping("/deleteArea")
    public ResultData deleteArea(@RequestBody Integer id) {
        int flag = areaService.deleteArea(id);
        if (flag > 0) {
            return ResultData.success();
        } else {
            return ResultData.fail(ErrorCode.FAIL);
        }
    }

    @ApiOperation(value = "修改区域")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "vo", value = "数据", dataType = "AreaVO", required = true)
    })
    @PostMapping("/updateArea")
    public ResultData updateArea(@RequestBody AreaVO vo) {
        int flag = areaService.updateArea(vo);
        if (flag > 0) {
            return ResultData.success();
        } else {
            return ResultData.fail(ErrorCode.FAIL);
        }
    }

    @ApiOperation(value = "查询所有区域")
    @GetMapping("/getAllAreas")
    public ResultData getAllAreas() {
        return ResultData.success(areaService.getAllAreas());
    }

    @ApiOperation(value = "根据级别查询区域")
    @GetMapping("/getAreasByType")
    public ResultData getAreasByType(Integer type) {
        return ResultData.success(areaService.getAreasByType(type));
    }
}
