package com.sw.patroleditor.controller;

import com.sw.patroleditor.common.ResultData;
import com.sw.patroleditor.component.rosBridge.RobotDataCallBack;
import com.sw.patroleditor.domain.model.FocusConfiguration;
import com.sw.patroleditor.domain.model.FocusData;
import com.sw.patroleditor.domain.model.PTZData;
import com.sw.patroleditor.domain.model.Position3D;
import com.sw.patroleditor.service.HKService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@Api(tags = {"云台功能"})
@RestController
public class PTZController {

    @Resource
    private HKService hkService;
    @Resource
    private RobotDataCallBack robotDataCallBack;

    @ApiOperation(value = "云台转动/递进")
    @PutMapping("/ptz/move")
    public ResultData move(@RequestBody PTZData ptzData) {
        return hkService.continuousChanged(ptzData);
    }


    @ApiOperation(value = "改变云台聚焦模式")
    @PutMapping("/ptz/changeFocusMode")
    public ResultData changeFocusMode(@RequestBody FocusConfiguration focusConfiguration) {
        return hkService.changeFocusMode(focusConfiguration);
    }


    @ApiOperation(value = "云台聚焦")
    @PutMapping("/ptz/focus")
    public ResultData focus(@RequestBody FocusData focusData) {
        return hkService.focusChanged(focusData);
    }


    @ApiOperation(value = "3D定位")
    @PutMapping("/ptz/position3D")
    public ResultData position3D(@RequestBody Position3D position3D) {
        return hkService.position3DCtrl(position3D);
    }

    @ApiOperation(value = "可见光抓图")
    @GetMapping("/ptz/picture")
    public ResultData picture() {
        return hkService.picture();
    }

    @ApiOperation(value = "机器人信息")
    @GetMapping("/robot/data")
    public ResultData getRobotData() {
        // 获取机器人数据
        return ResultData.success(robotDataCallBack.getRobotDataModel());
    }

}
